﻿'"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'  © Agilent Technologies, Inc. 2013

' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent Technologies has no
' warranty,  obligations or liability for any Sample Application Files.

' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent Technologies support engineers can help explain the
' functionality of Agilent Technologies software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

' This example shows you how to use the Agilent Advanced Power Supply to measure inrush current.  
' You use the built in digitizer to digitize the current during a transition from 0 volts to your final voltage.
' This program uses the Agilent VISA COM library to communicate with the instrument.

Option Explicit On
Imports Ivi.Visa.Interop



Module Module1

    Sub main()
        Dim ioMgr As ResourceManager
        Dim APS As FormattedIO488
        Dim IOAddress As String

        Dim strResponse As String
        Dim MeasCurrPoints() As Single
        Dim MeasVoltPoints() As Single
        Dim vSet, iSet, timeInt, vTrig, vFinal, max As Double
        Dim points, offset, i As Integer
        Const WTG_meas As Int32 = 8
        Const WTG_tran As Int32 = 16
        Const meas_active As Int32 = 32

        max = 0
        vSet = 0.0
        vFinal = 9.0
        iSet = 2.0
        vTrig = 1.0
        timeInt = 0.00000512
        points = 500000
        offset = -10000

        ' Set the instrument address.
        IOAddress = "TCPIP0::148.5.218.210"

        ' Start an I/O session.
        ioMgr = New ResourceManager
        APS = New FormattedIO488

        ' Connect to the instrument.
        APS.IO = ioMgr.Open(IOAddress, AccessMode.EXCLUSIVE_LOCK, 2000, "")

        ' Reset the instrument and clear all statuses.
        APS.WriteString("*RST;*CLS")

        ' Identify the instrument.
        APS.WriteString("*IDN?")
        strResponse = APS.IO.ReadString(256)
        Console.WriteLine("Instrument's IDN response:" & strResponse)

        ' Reading the data back in the real format instead of ASCII will provide the best time.
        APS.IO.WriteString("FORM REAL")

        ' Set the unit up to output voltage and current in voltage priority mode.
        ' Set the output voltage to 0 to begin so your DUT is powered off.
        APS.IO.WriteString("FUNC VOLT")
        APS.IO.WriteString("VOLT " & vSet.ToString)
        APS.IO.WriteString("CURR:LIM " & iSet.ToString)
        APS.IO.WriteString("OUTP 1")

        ' Use *OPC to ensure that the output is on.
        APS.IO.WriteString("*OPC?")
        strResponse = APS.IO.ReadString(4)

        ' Use a step transient to quickly step from o volts to your final voltage.
        APS.IO.WriteString("TRIG:TRAN:SOUR BUS")
        APS.IO.WriteString("VOLT:MODE STEP")
        APS.IO.WriteString("VOLT:TRIG " & vFinal.ToString)

        ' These commands set up the measurement system.  
        ' Use a voltage level trigger to take a measurement as the voltage rises. 
        ' The points command controls the total amount of points measured.
        ' Use a negative offset to return measurements before the trigger.
        'The time interval command is the time between digitized points. 
        APS.IO.WriteString("TRIG:ACQ:SOUR VOLT1")
        APS.IO.WriteString("TRIG:ACQ:VOLT:SLOP POS")
        APS.IO.WriteString("TRIG:ACQ:VOLT " & vTrig.ToString)
        APS.IO.WriteString("SENS:SWE:POIN " & points.ToString)
        APS.IO.WriteString("SENS:SWE:OFFS:POIN " & offset.ToString)
        APS.IO.WriteString("SENS:SWE:TINT " & timeInt.ToString)

        'Initiate tells the APS to initialize the measurement system and change voltages when it receives a trigger.
        APS.IO.WriteString("INIT:ACQ")
        APS.IO.WriteString("INIT:TRAN")

        ' You do not want to trigger the supply before the measurement and transient systems initiate. 
        ' Polling the status register enables you to determine exactly when the initializations are complete.  
        ' This is good practice to avoid errors.

        Do
            APS.IO.WriteString("STAT:OPER:COND?")
            strResponse = APS.IO.ReadString(32)
            i = Convert.ToInt32(strResponse)
        Loop Until ((i And (WTG_meas + WTG_tran)) = WTG_meas + WTG_tran)

        ' Trigger the voltage change.
        APS.IO.WriteString("*TRG")

        ' You do not want to fetch data before the measurement is complete. 
        ' Polling the status register enables you to determine exactly when measurement completes
        ' This is good practice to avoid annoying timeout errors.
        Do
            APS.IO.WriteString("STAT:OPER:COND?")
            strResponse = APS.IO.ReadString(32)
            i = Convert.ToInt32(strResponse)
        Loop Until ((i And meas_active) <> meas_active)

        'After the measurement is complete, you can fetch both the voltage and the current measurements
        APS.IO.WriteString("FETC:ARR:CURR?")
        MeasCurrPoints = APS.ReadIEEEBlock(IEEEBinaryType.BinaryType_R4)

        APS.IO.WriteString("FETC:ARR:VOLT?")
        MeasVoltPoints = APS.ReadIEEEBlock(IEEEBinaryType.BinaryType_R4)

        ' Determine what the maximum measured current is.
        i = 0

        While i < UBound(MeasCurrPoints)
            If MeasCurrPoints(i) > max Then max = MeasCurrPoints(i)
            i = i + 1
        End While

        Console.WriteLine("The measured inrush current= " & max & " A.")

        Console.WriteLine()

        APS.IO.Close()

        Console.WriteLine("Press Enter to exit")
        Console.ReadLine()

    End Sub


End Module
